/*
	Joe Sandbox generates four different rule types based on static and dynamic behavior data:

	 - Sample File (initial sample)
	 - Dropped File (files downloaded or stored during dynamic analysis)
	 - Opcode Memory (instruction opcodes from memory dumps of processes captured during dynamic analysis)

	A rule may be a simple or super rule. Compared to simple rules super rules include artifacts present in multiple files / analyses and are generic.
	Since most malware is packed sample and dropped file rules often do not provide meaningful detection results. In contrast string and opcode
	rules provide good detection capabilities. To scan memory with Yara you can use the specific process ID via command line or use our yarafullmemoryscan.bat to search
	accross all processes on a system.

	This rule file contains simple Dropped File rules. Artifact include strings and PE data.

	Automated rule generation is not perfect and therefore we encourage you to modify and extend the rules provided!
*/

import "pe"

rule sampe_m_dutch_wnry_3240_dr_1 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "m_dutch.wnry.3240.dr"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "dropped"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "7a8d499407c6a647c03c4471a67eaad7"
		sha1 = "d573b6ac8e7e04a05cbbd6b7f6a9842f371d343b"
		sha256 = "2c95bef914da6c50d7bdedec601e589fbb4fda24c4863a7260f4f72bd025799c"
		date = "12/05/2017"
	strings:
		// Relevance: 3.0 Appears at: 231a
		$s0 = "\\slocked" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 5b69
		$s1 = "\\lsdlocked0" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 301f
		$s2 = "decryptiedienst." fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 3275
		$s3 = "<Decrypt>" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 78b1
		$s4 = "5;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 904
		$s5 = "{\\f888\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 610d
		$s6 = "\\lsdpriority60" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1f87
		$s7 = "Font;}{\\*" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 219d
		$s8 = "Table;}{\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 344e
		$s9 = "evenementen" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 3487
		$s10 = "maanden" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 6047
		$s11 = "\\lsdpriority59" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2c25
		$s12 = "\\ltrpar\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 331e
		$s13 = "slechts" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 617d
		$s14 = "List;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 22af
		$s15 = "\\styrsid1119763" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 35e9
		$s16 = "alleen" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: af8
		$s17 = "Cyr;}{\\f953\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2ee6
		$s18 = "andere" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1f5f
		$s19 = "\\sunhideused" fullword nocase wide ascii
	condition:
		all of them
}
rule sampe_Sleep_Away_mp3_WNCRYT_3240_dr_2 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "Sleep Away.mp3.WNCRYT.3240.dr"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "dropped"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "15860aa73ab9f6c7c7bbfb741d3e4b1a"
		sha1 = "ff20ba5b6eae9669e6e671bac13e83ced9b06e83"
		sha256 = "1aba72a51e54f08ba6731ad1957834d61e229d322a65a8411229d1870b3ecf27"
		date = "12/05/2017"
	strings:
		// Relevance: 0.0 Appears at: 239097
		$s0 = "i#N\"zb" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 116452
		$s1 = ";%P0L=j" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 200c94
		$s2 = "uMu/Vkd" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 15b31e
		$s3 = "m;MTs-" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 90536
		$s4 = "&KI@iyY" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: cf002
		$s5 = "S\"5pdb" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2aed58
		$s6 = "tMB#\\~n" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 8a863
		$s7 = ":--0.&" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 5021d
		$s8 = "q<<V3a" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 19701a
		$s9 = "}ogOA-" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: aa14e
		$s10 = "+@r]_(" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2a0ec8
		$s11 = "ccD_X8.;g[m@V" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2c696a
		$s12 = "CDj<N.$" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 8
		$s13 = "WANACRY!" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: ecb27
		$s14 = "/.Ncn7" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 110128
		$s15 = "H^*wun" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 247ed
		$s16 = "::UKDC>" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 18d4c3
		$s17 = "90-IAE:#" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: a5054
		$s18 = "lX'uPg" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 125418
		$s19 = "*tPtm8" fullword nocase wide ascii
	condition:
		all of them
}
rule sampe_m_japanese_wnry_3240_dr_3 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "m_japanese.wnry.3240.dr"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "dropped"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "b77e1221f7ecd0b5d696cb66cda1609e"
		sha1 = "51eb7a254a33d05edf188ded653005dc82de8a46"
		sha256 = "7e491e7b48d6e34f916624c1cda9f024e86fcbec56acda35e27fa99d530d017e"
		date = "12/05/2017"
	strings:
		// Relevance: 3.0 Appears at: 2920
		$s0 = "\\slocked" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 1095b
		$s1 = "\\lsdlocked0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 126a3
		$s2 = "5;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 259d
		$s3 = "Font;}{\\*" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: c2b
		$s4 = "Cyr{\\*\\falt" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 10eff
		$s5 = "\\lsdpriority60" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 27b3
		$s6 = "Table;}{\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1b8
		$s7 = "Mincho{\\*\\falt" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: bc1c
		$s8 = "11}{\\rtlch\\fcs1" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 9e7
		$s9 = "Cyr;}{\\f563\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 9ae
		$s10 = "{\\f561\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 10e39
		$s11 = "\\lsdpriority59" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 10bd
		$s12 = "\\'b0\\'ed\\'b5\\'f1" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 3230
		$s13 = "\\ltrpar\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 10f6f
		$s14 = "List;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 113e
		$s15 = "Cyr;}{\\f953\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: b57
		$s16 = "{\\f652\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2575
		$s17 = "\\sunhideused" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 452
		$s18 = "Mincho;}" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 11321
		$s19 = "Accent" fullword nocase wide ascii
	condition:
		all of them
}
rule sampe_m_danish_wnry_3240_dr_4 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "m_danish.wnry.3240.dr"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "dropped"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "2c5a3b81d5c4715b7bea01033367fcb5"
		sha1 = "b548b45da8463e17199daafd34c23591f94e82cd"
		sha256 = "a75bb44284b9db8d702692f84909a7e23f21141866adf3db888042e9109a1cb6"
		date = "12/05/2017"
	strings:
		// Relevance: 3.0 Appears at: 325f
		$s0 = "<Decrypt>." fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 22d4
		$s1 = "\\slocked" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 3089
		$s2 = "filer?" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 5b9b
		$s3 = "\\lsdlocked0" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 24e4
		$s4 = "http://schemas.micr" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 32b7
		$s5 = "filer," fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 78e3
		$s6 = "5;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 613f
		$s7 = "\\lsdpriority60" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1f51
		$s8 = "Font;}{\\*" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2167
		$s9 = "Table;}{\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: a97
		$s10 = "{\\f883\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 686
		$s11 = "CE;}{\\f541\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 6079
		$s12 = "\\lsdpriority59" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2de
		$s13 = "{\\f41\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: d49
		$s14 = "\\'b0\\'ed\\'b5\\'f1" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 37d9
		$s15 = "nuv\\'e6\\loch\\f31502" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2be6
		$s16 = "\\ltrpar\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 3dae
		$s17 = "<Contact" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 61af
		$s18 = "List;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 3d85
		$s19 = "besked" fullword nocase wide ascii
	condition:
		all of them
}
rule sampe_m_russian_wnry_3240_dr_5 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "m_russian.wnry.3240.dr"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "dropped"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "452615db2336d60af7e2057481e4cab5"
		sha1 = "442e31f6556b3d7de6eb85fbac3d2957b7f5eac6"
		sha256 = "02932052fafe97e6acaaf9f391738a3a826f5434b1a013abbfa7a6c1ade1e078"
		date = "12/05/2017"
	strings:
		// Relevance: 3.0 Appears at: 3efc
		$s0 = "<Decrypt>." fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 22d4
		$s1 = "\\slocked" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 81fe
		$s2 = "\\lsdlocked0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 34e1
		$s3 = "\\'ed\\'e5\\loch\\f31529" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 9f46
		$s4 = "5;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1f51
		$s5 = "Font;}{\\*" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 87a2
		$s6 = "\\lsdpriority60" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2167
		$s7 = "Table;}{\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: a97
		$s8 = "{\\f883\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 686
		$s9 = "CE;}{\\f541\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 3ef1
		$s10 = "\\'fc\\loch\\f31529" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2de
		$s11 = "{\\f41\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 86dc
		$s12 = "\\lsdpriority59" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 3121
		$s13 = "\\'e8\\loch\\f31529" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: d49
		$s14 = "\\'b0\\'ed\\'b5\\'f1" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2bdb
		$s15 = "\\ltrpar\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 64a0
		$s16 = "\\'ee\\'ed\\loch\\f31529" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 8812
		$s17 = "List;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: dcb
		$s18 = "Cyr;}{\\f953\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1f29
		$s19 = "\\sunhideused" fullword nocase wide ascii
	condition:
		all of them
}
rule sampe_Lighthouse_jpg_WNCRYT_3240_dr_6 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "Lighthouse.jpg.WNCRYT.3240.dr"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "dropped"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "0a8aac33bc13fd3bf3b8ee48e938492a"
		sha1 = "dec9a4edfa28c7dff796939ddb2e17d25a029fe3"
		sha256 = "e8ba66fb08f678a5f497a0b47298c21af58b08d46a94acfae8f68a9021f3f6f6"
		date = "12/05/2017"
	strings:
		// Relevance: 0.0 Appears at: 26639
		$s0 = "\"kNy}Of" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2e503
		$s1 = "AqBi@g" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 504f0
		$s2 = "|Fnig)!" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 4d9cf
		$s3 = "jq!d$2" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 8
		$s4 = "WANACRY!" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 5cd
		$s5 = "YB!T7i" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: c4d5
		$s6 = "b?dzyC'" fullword nocase wide ascii
	condition:
		all of them
}
rule sampe_Penguins_jpg_WNCRYT_3240_dr_7 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "Penguins.jpg.WNCRYT.3240.dr"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "dropped"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "2743f47edd5e95962dc99b1695109154"
		sha1 = "70fa154860ca5c1bffe3df7613be56e9bb927d11"
		sha256 = "9c019bdcca3e80ca1d6a4bb88296d8ebffb60c1faad2e94ef42369770dd99d74"
		date = "12/05/2017"
	strings:
		// Relevance: 0.0 Appears at: 29fab
		$s0 = ",p}-\\;<P'" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 8f86
		$s1 = "@GV&zt" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 37386
		$s2 = "=V\"jax#t" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 71c7e
		$s3 = "(2i.N$" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1c73e
		$s4 = "\\/.=B,Jc3*" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 9b41
		$s5 = "e\"7rG+" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 8
		$s6 = "WANACRY!" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 374df
		$s7 = "AI72o_U" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 21c5d
		$s8 = "v{vxTc" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 9d9e
		$s9 = "ze.<\\j" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1aa88
		$s10 = "qNV/0A" fullword nocase wide ascii
	condition:
		all of them
}
rule sampe_m_filipino_wnry_3240_dr_8 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "m_filipino.wnry.3240.dr"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "dropped"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "08b9e69b57e4c9b966664f8e1c27ab09"
		sha1 = "2da1025bbbfb3cd308070765fc0893a48e5a85fa"
		sha256 = "d8489f8c16318e524b45de8b35d7e2c3cd8ed4821c136f12f5ef3c9fc3321324"
		date = "12/05/2017"
	strings:
		// Relevance: 3.0 Appears at: 330b
		$s0 = "<Decrypt>." fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 304f
		$s1 = "decryption" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 231a
		$s2 = "\\slocked" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 5db4
		$s3 = "\\lsdlocked0" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 2e80
		$s4 = "naka-encrypt." fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 32ae
		$s5 = "i-decrypt" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 3cf8
		$s6 = "pag-decrypt" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 2f38
		$s7 = "nai-naka-encrypt." fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 7afc
		$s8 = "5;\\lsdsemihidden0" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 904
		$s9 = "{\\f888\\fbidi" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 6358
		$s10 = "\\lsdpriority60" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 1f87
		$s11 = "Font;}{\\*" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 34d0
		$s12 = "magpakailanman." fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 219d
		$s13 = "Table;}{\\s15\\ql" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 3c1b
		$s14 = "Pinakamahusay" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 40b5
		$s15 = "paganahin" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 3720
		$s16 = "impormasyon," fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 2dbe
		$s17 = "Computer?" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 6292
		$s18 = "\\lsdpriority59" fullword nocase wide ascii
		// Relevance: 0.0 Appears at: 30fa
		$s19 = "Maaari" fullword nocase wide ascii
	condition:
		all of them
}
