/*
	Joe Sandbox generates four different rule types based on static and dynamic behavior data:

	 - Sample File (initial sample)
	 - Dropped File (files downloaded or stored during dynamic analysis)
	 - Opcode Memory (instruction opcodes from memory dumps of processes captured during dynamic analysis)

	A rule may be a simple or super rule. Compared to simple rules super rules include artifacts present in multiple files / analyses and are generic.
	Since most malware is packed sample and dropped file rules often do not provide meaningful detection results. In contrast string and opcode
	rules provide good detection capabilities. To scan memory with Yara you can use the specific process ID via command line or use our yarafullmemoryscan.bat to search
	accross all processes on a system.

	This rule file contains simple Opcode Memory rules. Artifact include strings and PE data.

	Automated rule generation is not perfect and therefore we encourage you to modify and extend the rules provided!
*/

/*
	Process overview from dynamic analysis:
	id: 0 name: mssecsvc.exe
		id: 3 name: tasksche.exe
	id: 2 name: mssecsvc.exe
	id: 4 name: cmd.exe
		id: 5 name: tasksche.exe
			id: 6 name: attrib.exe
			id: 7 name: icacls.exe
			id: 10 name: taskdl.exe
			id: 11 name: cmd.exe
				id: 13 name: cscript.exe
			id: 14 name: @WanaDecryptor@.exe
				id: 19 name: taskhsvc.exe
			id: 15 name: cmd.exe
				id: 18 name: @WanaDecryptor@.exe
					id: 27 name: cmd.exe
						id: 29 name: vssadmin.exe
						id: 32 name: WMIC.exe
						id: 33 name: bcdedit.exe
						id: 34 name: bcdedit.exe
						id: 35 name: wbadmin.exe
			id: 21 name: taskse.exe
				id: 25 name: @WanaDecryptor@.exe
			id: 22 name: cmd.exe
				id: 26 name: reg.exe
			id: 23 name: taskdl.exe
			id: 37 name: taskdl.exe
			id: 38 name: taskse.exe
	id: 36 name: wbengine.exe
	id: 39 name: vdsldr.exe
*/

rule sampe__WanaDecryptor__exe_9 {
	meta:
		description = "Auto-generated simple rule for memory"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		joesandboxid = "269081"
		detection = "malicious"
		source = "memory dumps from processes: process id: 14 frame id: 2 base address: 400000"
		ruletype = "memorycode"
		md5 = "7BF2B57F2A205768755C07F238FB32CC"
		superrule = "no"
		date = "12/05/2017"
	strings:
		// Relevance: 130.036  API Chain: SendMessageA,CreateSolidBrush,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateSolidBrush,#1641,CreateFontA,CreateFontA,#1641,CreateFontA,#1641,CreateFontA,#1641,#3092,SendMessageA,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#3092,SendMessageA,#860,#537,#537,#540,#2818,#535,#2818,#535,SendMessageA,SendMessageA,#6140,#6140,GetTimeZoneInformation,SystemTimeToTzSpecificLocalTime,SystemTimeToTzSpecificLocalTime,#2818,SystemTimeToTzSpecificLocalTime,#2818,#6334,#800,
		$code0 = { ?? A1 ?? ?? ?? ?? 6A ?? 68 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 53 55 56 57 8B ?? 6A ?? E8 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? 50 8D ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? 50 8D ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? 50 8D ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? 50 8D ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 6A ?? FF ?? 50 8D ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? 50 8D ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? 50 8D ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? 50 8D ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ??  }
		// Relevance: 56.454  API Chain: #540,#3874,#860,#860,_ftol,SendMessageA,#2860,#5875,#6170,GetWindowOrgEx,#540,#2818,GetObjectA,GetTextExtentPoint32A,GetViewportOrgEx,#800,#6170,#5875,#2414,#2414,#800,
		$code1 = { ?? A1 ?? ?? ?? ?? 6A ?? 68 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 53 8B ?? ?? ?? ?? ?? ?? 55 56 8B ?? ?? 57 F6 ?? ?? 8B ?? 0F 84 ?? ?? ?? ?? 8B ?? 83 ?? ?? 33 ?? 8D ?? ?? ?? 89 ?? ?? ?? 89 ?? ?? ?? E8 ?? ?? ?? ?? 8D ?? ?? ?? 8B ?? 50 89 ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 8B ?? ?? 25 ?? ?? ?? ?? 3D ?? ?? ?? ?? 74 ?? 3D ?? ?? ?? ?? 75 ?? 8B ?? ?? ?? 39 ?? ?? 75 ?? 68 ?? ?? ?? ?? 8D ?? ?? ?? E8 ?? ?? ?? ?? 8B ?? ?? 89 ?? ?? ?? EB ?? 8B ?? ?? ?? 39 ?? ?? 75 ?? 68 ?? ?? ?? ?? 8D ?? ?? ?? E8 ?? ?? ?? ?? 8B ?? ?? 8B ?? ?? 8B ?? ?? 2B ?? 89 ?? ?? ?? 2B ?? DB ?? ?? ?? 89 ?? ?? ?? D8 ??  }
		// Relevance: 54.568  API Chain: swprintf,FindFirstFileW,#825,#825,wcscmp,wcslen,wcscmp,wcscmp,swprintf,GetFileAttributesW,?_Tidy@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@AAEX_N@Z,wcslen,?assign@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@QAEAAV12@PBGI@Z,wcscmp,wcscmp,wcscmp,?_Tidy@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@AAEX_N@Z,wcslen,?assign@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@QAEAAV12@PBGI@Z,?_Tidy@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@AAEX_N@Z,FindNextFileW,FindClose,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,swprintf,swprintf,DeleteFileW,swprintf,DeleteFileW,#825,#825,
		$code2 = { 6A ?? 68 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 8A ?? ?? ?? 53 55 33 ?? 8B ?? 53 53 8D ?? ?? ?? 88 ?? ?? ?? E8 ?? ?? ?? ?? 89 ?? ?? ?? 89 ?? ?? ?? 8A ?? ?? ?? 53 88 ?? ?? ?? 53 8D ?? ?? ?? 89 ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 89 ?? ?? ?? 89 ?? ?? ?? 8B ?? ?? ?? ?? ?? ?? 8D ?? ?? ?? 52 68 ?? ?? ?? ?? 50 C6 ?? ?? ?? ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 83 ?? ?? 8D ?? ?? ?? ?? ?? ?? 8D ?? ?? ?? 51 52 FF ?? ?? ?? ?? ?? 83 ?? ?? 89 ?? ?? ?? 75 ?? 8B ?? ?? ?? 88 ?? ?? ?? ?? ?? ?? 50 8B ?? 8D ?? ?? ?? 51 50 8D ?? ?? ?? E8 ?? ?? ?? ?? 8B ?? ?? ?? 51 E8 ?? ?? ?? ?? 8B ?? ??  }
		// Relevance: 49.779  API Chain: #940,#4277,#923,#858,#800,#800,#4129,#5710,#922,#858,#800,#800,#800,#940,#5710,#4129,#922,#858,#800,#800,#800,#4129,#4277,#922,#858,#800,#800,#800,#6778,#6648,#6778,#6648,InvalidateRect,
		$code3 = { ?? A1 ?? ?? ?? ?? 6A ?? 68 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 83 ?? ?? 53 55 56 8B ?? 57 8B ?? ?? 83 ?? ?? 0F 85 ?? ?? ?? ?? 38 ?? ?? 75 ?? 8B ?? ?? 8D ?? ?? 8B ?? ?? 8B ?? ?? 3B ?? 7D ?? 2B ?? 85 ?? 7E ?? 8B ?? 8A ?? ?? 51 8B ?? E8 ?? ?? ?? ?? 4B 75 ?? 8B ?? ?? 8D ?? ?? 85 ?? 75 ?? 8B ?? 8D ?? ?? ?? 6A ?? 51 8A ?? 8B ?? 88 ?? ?? ?? E8 ?? ?? ?? ?? 8B ?? ?? ?? C7 ?? ?? ?? ?? ?? ?? ?? 52 50 8D ?? ?? ?? 50 E8 ?? ?? ?? ?? 50 8B ?? C6 ?? ?? ?? ?? E8 ?? ?? ?? ?? 8D ?? ?? ?? C6 ?? ?? ?? ?? E8 ?? ?? ?? ?? 8D ?? ?? ?? C7 ?? ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? E9 ?? ?? ?? ?? 8B ?? 8D ?? ?? ?? 8B ?? ?? 8B }
		// Relevance: 47.431  API Chain: __p___argv,#4278,#858,#800,#1200,#800,time,time,#540,time,#2818,#1200,#800,#800,time,fopen,#800,fread,fclose,#1200,time,#1200,#800,
		$code4 = { 6A ?? 68 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 53 55 56 57 8B ?? 8B ?? ?? ?? ?? ?? ?? 33 ?? 89 ?? ?? ?? ?? ?? ?? 8B ?? ?? 3D ?? ?? ?? ?? 7E ?? 68 ?? ?? ?? ?? 8D ?? ?? ?? 53 51 8D ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 50 8D ?? ?? ?? ?? ?? ?? C6 ?? ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 8D ?? ?? ?? 88 ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? ?? 83 ?? ?? ?? 7D ?? 39 ?? ?? ?? ?? ?? ?? 74 ?? 53 53 68 ?? ?? ?? ?? E8 ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? ?? C7 ?? ?? ?? ?? ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 83 ?? ?? E9 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 53 FF ?? 8B ?? ?? ?? ?? ?? 83 }
		// Relevance: 45.859  API Chain: CreateFileW,GetFileTime,ReadFile,ReadFile,ReadFile,ReadFile,ReadFile,CloseHandle,CreateFileW,SetFilePointer,SetFilePointer,ReadFile,SetFilePointer,WriteFile,SetFilePointer,SetEndOfFile,CreateFileW,ReadFile,WriteFile,_local_unwind2,SetFilePointerEx,SetEndOfFile,SetFileTime,CloseHandle,MoveFileW,_local_unwind2,
		$code5 = { 55 8B ?? 6A ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 53 56 57 89 ?? ?? ?? ?? ?? 83 ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 33 ?? 89 ?? ?? 89 ?? ?? ?? ?? ?? C6 ?? ?? ?? ?? ?? ?? 33 ?? 89 ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 88 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? 89 ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? 56 56 6A ?? 56 6A ?? 68 ?? ?? ?? ?? 8B ?? ?? 51 FF ?? ?? ?? ?? ?? 8B ?? 89 ?? ?? ?? ?? ?? 3B ?? 75 ?? 57 8D ?? ?? 52 E9 ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? 50 8D ?? ?? ?? ?? ?? 51 8D ?? ?? ?? ?? ?? 52 53 FF ?? ?? ?? ?? ?? 56 8D ?? ?? 50 6A ?? 8D  }
		// Relevance: 45.756  API Chain: #4710,SendMessageA,SendMessageA,SendMessageA,GetModuleFileNameA,strrchr,strrchr,strrchr,SetCurrentDirectoryA,time,WSAStartup,__p___argc,__p___argv,__p___argv,ExitProcess,__p___argv,ExitProcess,__p___argv,Sleep,sprintf,ExitProcess,SetWindowTextW,SetTimer,SetTimer,SetTimer,
		$code6 = { 81 ?? ?? ?? ?? ?? 53 55 56 57 8B ?? E8 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 8B ?? ?? 8B ?? ?? ?? ?? ?? 50 6A ?? 68 ?? ?? ?? ?? 51 FF ?? 8B ?? ?? ?? ?? ?? 8B ?? ?? 52 6A ?? 68 ?? ?? ?? ?? 50 FF ?? 6A ?? E8 ?? ?? ?? ?? 83 ?? ?? 85 ?? 75 ?? 8A ?? ?? ?? ?? ?? 8D ?? ?? ?? 88 ?? ?? ?? B9 ?? ?? ?? ?? ?? AB ?? AB 8D ?? ?? ?? 68 ?? ?? ?? ?? 52 6A ?? AA FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 8D ?? ?? ?? 6A ?? 50 FF ?? 83 ?? ?? 85 ?? 74 ?? 8D ?? ?? ?? 6A ?? 51 FF ?? 83 ?? ?? C6 ?? ?? 8D ?? ?? ?? 52 FF ?? ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? 6A ?? 55 E8 ?? ?? ?? ?? 83 ?? ?? 85 ?? 75 ?? B9 ?? ?? ?? ?? 8B ?? ?? AB BF ??  }
		// Relevance: 40.574  API Chain: #470,GetClientRect,SendMessageA,#6734,#323,CreateCompatibleDC,#1640,#6194,FillRect,#2754,#2381,#3797,_ftol,_ftol,FillRect,FillRect,#5785,#5785,#640,#755,
		$code7 = { 6A ?? 68 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 53 56 8B ?? 57 56 8D ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 8B ?? ?? 8D ?? ?? ?? 33 ?? 50 51 89 ?? ?? ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8B ?? ?? 53 53 68 ?? ?? ?? ?? 52 FF ?? ?? ?? ?? ?? 89 ?? ?? ?? 8D ?? ?? ?? 8D ?? ?? ?? 50 51 8B ?? E8 ?? ?? ?? ?? 8D ?? ?? ?? E8 ?? ?? ?? ?? 8D ?? ?? ?? C6 ?? ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? C7 ?? ?? ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? ?? 33 ?? 3B ?? BF ?? ?? ?? ?? 0F 94 ?? 8D ?? ?? ?? ?? ?? ?? 3B ?? C6 ?? ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? 89 ?? ?? ?? 89 ?? ?? ?? 89 ?? ?? ?? 0F 84 ?? ?? ?? ?? 8B }
		// Relevance: 40.383  API Chain: wcscmp,wcslen,_wcsnicmp,wcsstr,wcsstr,_wcsicmp,_wcsicmp,_wcsicmp,_wcsicmp,_wcsicmp,_wcsicmp,wcsstr,wcsstr,_wcsicmp,_wcsicmp,_wcsicmp,
		$code8 = { 53 56 8B ?? ?? ?? 57 6A ?? 68 ?? ?? ?? ?? 56 FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 83 ?? ?? 85 ?? 75 ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? EB ?? 8D ?? ?? 8B ?? ?? ?? ?? ?? 85 ?? 0F 84 ?? ?? ?? ?? 8D ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ??  }
		// Relevance: 38.64  API Chain: #6453,WaitForSingleObject,TerminateThread,CloseHandle,sprintf,fopen,fread,fclose,DeleteFileA,#537,#924,#1200,#800,#800,#1200,rand,#1200,
		$code9 = { ?? A1 ?? ?? ?? ?? 6A ?? 68 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 53 56 57 8B ?? E8 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 33 ?? 3B ?? 74 ?? 68 ?? ?? ?? ?? 50 FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 53 50 FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 51 FF ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 39 ?? ?? ?? ?? ?? 0F 85 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 83 ?? ?? 0F 85 ?? ?? ?? ?? B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? 88 ?? ?? ?? ?? AB ?? AB AA B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? ?? ?? ?? 88 ?? ?? ?? ?? ?? ?? ?? AB ?? AB 53 8D ?? ?? ?? 68 ?? ?? ?? ?? 52 AA FF ?? ?? ?? ?? ?? 8D ?? ?? ?? 68 ?? ?? ?? ?? 50 FF ?? ?? ?? ?? ?? 8B }
	condition:
		all of them
}
rule sampe_tasksche_exe_10 {
	meta:
		description = "Auto-generated simple rule for memory"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		joesandboxid = "269081"
		detection = "malicious"
		source = "memory dumps from processes: process id: 5 frame id: 2 base address: 10000000"
		ruletype = "memorycode"
		md5 = "84C82835A5D21BBCF75A61706D8AB549"
		superrule = "no"
		date = "12/05/2017"
	strings:
		// Relevance: 75.848  API Chain: CreateFileW,CreateFileW,GetFileSizeEx,GetFileTime,ReadFile,ReadFile,ReadFile,ReadFile,_local_unwind2,SetFilePointer,SetFilePointer,swprintf,CreateFileW,CreateFileW,ReadFile,SetFilePointer,WriteFile,SetFilePointer,WriteFile,SetFilePointer,rand,WriteFile,WriteFile,WriteFile,WriteFile,WriteFile,SetFilePointer,ReadFile,WriteFile,SetFilePointer,ReadFile,WriteFile,_local_unwind2,SetFileTime,CloseHandle,CloseHandle,MoveFileW,SetFileAttributesW,DeleteFileW,CloseHandle,MoveFileW,_local_unwind2,
		$code0 = { 55 8B ?? 6A ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 53 56 57 8B ?? ?? A1 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? ?? ?? ?? AB ?? AB 83 ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? BF ?? ?? ?? ?? 8D ?? ?? 89 ?? ?? ?? ?? ?? 33 ?? 89 ?? ?? ?? ?? ?? 88 ?? ?? ?? ?? ?? 33 ?? 89 ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 88 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? 83 ?? ?? ?? 75 ?? BF ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 6A ?? 6A ?? 6A ?? 6A ?? 6A ?? 57 8B ?? ?? 50 FF ?? ?? ?? ?? ?? 8B }
		// Relevance: 59.723  API Chain: TaskStart,GetModuleFileNameW,wcsrchr,wcsrchr,wcsrchr,SetCurrentDirectoryW,sprintf,sprintf,sprintf,sprintf,??2@YAPAXI@Z,DeleteFileA,CreateThread,CreateThread,CloseHandle,CloseHandle,Sleep,Sleep,CreateThread,CloseHandle,Sleep,CreateThread,Sleep,CreateThread,CloseHandle,Sleep,CreateThread,CloseHandle,Sleep,WaitForSingleObject,CloseHandle,CreateThread,WaitForSingleObject,CloseHandle,
		$code1 = { ?? A1 ?? ?? ?? ?? 6A ?? 68 ?? ?? ?? ?? 50 8B ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 53 33 ?? 56 3B ?? 57 0F 85 ?? ?? ?? ?? E8 ?? ?? ?? ?? 85 ?? 0F 85 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? ?? AB 8D ?? ?? ?? 68 ?? ?? ?? ?? 51 52 ?? AB FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 8D ?? ?? ?? 6A ?? 50 FF ?? 83 ?? ?? 85 ?? 74 ?? 8D ?? ?? ?? 6A ?? 51 FF ?? 83 ?? ?? ?? 89 ?? 8D ?? ?? ?? 52 FF ?? ?? ?? ?? ?? 6A ?? 68 ?? ?? ?? ?? E8 ?? ?? ?? ?? 83 ?? ?? 85 ?? 0F 84 ?? ?? ?? ?? E8 ?? ?? ?? ?? A3 ?? ?? ?? ?? E8 ?? ?? ?? ?? 85 ?? 0F 84 ?? ??  }
		// Relevance: 49.373  API Chain: CloseHandle,SHGetFolderPathW,??2@YAPAXI@Z,swprintf,FindFirstFileW,??3@YAXPAX@Z,??3@YAXPAX@Z,wcscmp,wcscmp,wcscmp,swprintf,?_Tidy@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@AAEX_N@Z,wcslen,?assign@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@QAEAAV12@PBGI@Z,?_Tidy@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@AAEX_N@Z,wcscmp,wcscmp,wcscmp,wcsncpy,wcsncpy,wcsncpy,FindNextFileW,FindClose,_wcsnicmp,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,??3@YAXPAX@Z,??3@YAXPAX@Z,??3@YAXPAX@Z,
		$code2 = { 6A ?? 68 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 8A ?? ?? ?? 53 55 56 57 8B ?? 68 ?? ?? ?? ?? 89 ?? ?? ?? 88 ?? ?? ?? E8 ?? ?? ?? ?? 33 ?? 89 ?? 89 ?? ?? 83 ?? ?? 89 ?? ?? ?? 89 ?? ?? ?? 8A ?? ?? ?? 56 88 ?? ?? ?? 56 8D ?? ?? ?? 89 ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 89 ?? ?? ?? 89 ?? ?? ?? 8B ?? ?? ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? ?? 53 68 ?? ?? ?? ?? 52 C6 ?? ?? ?? ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 83 ?? ?? 8D ?? ?? ?? 8D ?? ?? ?? ?? ?? ?? 50 51 FF ?? ?? ?? ?? ?? 8B ?? 83 ?? ?? 89 ?? ?? ?? 75 ?? 8B ?? ?? ?? 8D ?? ?? ?? 50 C6 ?? ?? ?? ?? ?? ?? ?? 8B ?? 51 52 8D ?? ??  }
		// Relevance: 43.977  API Chain: CreateThread,GetFileAttributesA,time,sprintf,CloseHandle,GetDriveTypeW,Sleep,InterlockedExchange,GetLogicalDrives,GetDriveTypeW,GetDriveTypeW,InterlockedExchange,sprintf,time,sprintf,GetDriveTypeW,Sleep,
		$code3 = { 6A ?? 68 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 81 ?? ?? ?? ?? ?? 56 8D ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? 33 ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 85 ?? 0F 84 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 83 ?? ?? 75 ?? 6A ?? 6A ?? 8D ?? ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 39 ?? ?? ?? ?? ?? 75 ?? 56 FF ?? ?? ?? ?? ?? 83 ?? ?? A3 ?? ?? ?? ?? E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? 8D ?? ?? ?? 68 ?? ?? ?? ?? 50 FF ?? ?? ?? ?? ?? 56 8D ?? ?? ?? 68 ?? ?? ?? ?? 51 E8 ?? ?? ?? ?? 6A ?? 68 ?? ?? ?? ?? E8 ?? ?? ?? ?? 83 ?? ?? E8 ?? ??  }
		// Relevance: 38.633  API Chain: wcscmp,_wcsnicmp,wcsstr,wcsstr,_wcsicmp,_wcsicmp,_wcsicmp,_wcsicmp,_wcsicmp,_wcsicmp,wcsstr,wcsstr,_wcsicmp,_wcsicmp,_wcsicmp,
		$code4 = { 53 56 8B ?? ?? ?? 57 6A ?? 68 ?? ?? ?? ?? 56 FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 83 ?? ?? 85 ?? 75 ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? EB ?? 8D ?? ?? 8B ?? ?? ?? ?? ?? 85 ?? 0F 84 ?? ?? ?? ?? 8D ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E B8 ?? ?? ?? ?? 5B C2 ?? ?? 68 ??  }
		// Relevance: 35.13  API Chain: Sleep,EnterCriticalSection,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,wcslen,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,MoveFileExW,GetFileAttributesW,GetFileAttributesW,SetFileAttributesW,MoveFileExW,swprintf,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,MoveFileExW,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,DeleteFileW,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,GetFileAttributesW,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,SetFileAttributesW,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,MoveFileExW,??3@YAXPAX@Z,?_C@?1??_Nullstr@?$basic_string@GU?$char_traits@G@std@@V?$allocator@G@2@@std@@CAPBGXZ@4GB,??3@YAXPAX@Z,LeaveCriticalSection,ExitThread,
		$code5 = { 53 55 56 8B ?? 33 ?? 57 39 ?? ?? ?? ?? ?? 0F 85 ?? ?? ?? ?? 33 ?? 39 ?? ?? ?? ?? ?? 0F 85 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 47 83 ?? ?? 7C ?? 39 ?? ?? ?? ?? ?? 0F 85 ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? 50 FF ?? ?? ?? ?? ?? 39 ?? ?? ?? ?? ?? 0F 86 ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 8B ?? 83 ?? ?? 8B ?? ?? 3B ?? 74 ?? 8B ?? 55 FF ?? ?? ?? ?? ?? 83 ?? ?? 85 ?? 76 ?? 6A ?? 55 57 FF ?? ?? ?? ?? ?? 85 ?? 75 ?? 55 FF ?? ?? ?? ?? ?? 83 ?? ?? 74 ?? 55 FF ?? ?? ?? ?? ?? 0C ?? 50 55 FF ?? ?? ?? ?? ?? 6A ?? 53 55 FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 8D  }
		// Relevance: 31.7  API Chain: CloseHandle,SHGetFolderPathW,wcslen,SHGetFolderPathW,SHGetFolderPathW,wcslen,wcsrchr,wcschr,SHGetFolderPathW,wcslen,wcsrchr,swprintf,FindFirstFileW,wcscmp,wcscmp,swprintf,wcscmp,swprintf,FindNextFileW,FindClose,
		$code6 = { 81 ?? ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 53 55 56 57 B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? ?? 89 ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? ?? ?? AB ?? AB B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? ?? AB ?? AB 8B ?? ?? ?? ?? ?? ?? 8D ?? ?? ?? 33 ?? 50 56 56 57 56 FF ?? 8D ?? ?? ?? 51 FF ?? ?? ?? ?? ?? 83 ?? ?? 83 ?? ?? 73 ?? 5F 5E 5D 33 ?? 5B 81 ?? ?? ?? ?? ?? C3 8D ?? ?? ?? 6A ?? 52 FF ?? ?? ?? ?? ?? 8B ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E 5D 5B 81 ?? ?? ?? ?? ?? C3 8D ?? ?? ?? 6A ?? ?? C7 ?? ?? ?? 50 83 ?? ?? FF ?? ?? ?? ?? ?? 83 ?? ?? 85 ?? 75 ?? 5F 5E 5D 5B 81 ?? ?? ?? ?? ?? C3 83 ?? ?? ?? C7 ??  }
		// Relevance: 29.839  API Chain: Sleep,GetFileAttributesW,fopen,fread,fclose,fclose,_wfopen,_ftol,sprintf,sprintf,sprintf,sprintf,sprintf,fwrite,fclose,
		$code7 = { B8 ?? ?? ?? ?? E8 ?? ?? ?? ?? 53 56 57 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 83 ?? ?? 0F 85 ?? ?? ?? ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8B ?? 83 ?? ?? 85 ?? 0F 84 ?? ?? ?? ?? B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? C6 ?? ?? ?? ?? ?? AB ?? AB AA 56 68 ?? ?? ?? ?? 8D ?? ?? ?? 6A ?? 50 FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 56 FF ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8B ?? 83 ?? ?? 85 ?? 0F 84 ?? ?? ?? ?? A1 ?? ?? ?? ?? 85 ?? 75 ?? D9 ?? ?? ?? ?? ?? E8 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 50 8D ?? ?? ?? 68 ?? ?? ?? ?? 51 FF ?? 83 ?? ?? EB ?? D9 ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 83 ?? ?? 8D }
		// Relevance: 28.072  API Chain: wcsrchr,CreateFileW,LoadLibraryA,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,CreateFileW,WriteFile,ReadFile,MoveFileW,MoveFileExW,DeleteFileW,
		$code8 = { 56 E8 ?? ?? ?? ?? 85 ?? 0F 84 ?? ?? ?? ?? A1 ?? ?? ?? ?? 85 ?? 74 ?? B8 ?? ?? ?? ?? 5E C3 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8B ?? 85 ?? 0F 84 ?? ?? ?? ?? 57 8B ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 56 FF ?? 68 ?? ?? ?? ?? 56 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 56 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 56 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 56 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 56 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 56 A3 ?? ?? ?? ?? FF ?? 8B ?? ?? ?? ?? ?? A3 ?? ?? ?? ?? 85 ?? 5F 74 ?? 8B ?? ?? ?? ?? ?? 85 ?? 74 ?? 8B ?? ?? ?? ?? ?? 85 ?? 74 ?? 8B ?? ?? ?? ?? ?? 85 ?? 74 ?? 8B ?? ?? ?? ?? ?? 85 ?? 74  }
		// Relevance: 26.367  API Chain: GetDriveTypeW,GlobalAlloc,CreateFileW,GlobalFree,GetDriveTypeW,MoveFileExW,Sleep,GetDiskFreeSpaceExW,WriteFile,Sleep,Sleep,GlobalFree,FlushFileBuffers,CloseHandle,DeleteFileW,
		$code9 = { 81 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 53 56 8B ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? 8D ?? ?? ?? 57 8D ?? ?? 50 89 ?? ?? ?? ?? 89 ?? ?? ?? FF ?? ?? ?? ?? ?? 83 ?? ?? 0F 85 ?? ?? ?? ?? 68 ?? ?? ?? ?? 6A ?? FF ?? ?? ?? ?? ?? 8B ?? 85 ?? 0F 84 ?? ?? ?? ?? B9 ?? ?? ?? ?? B8 ?? ?? ?? ?? 8B ?? ?? AB B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? ?? C7 ?? ?? ?? ?? ?? ?? AB 8D ?? ?? ?? 51 56 ?? AB E8 ?? ?? ?? ?? 83 ?? ?? 8D ?? ?? ?? 6A ?? 6A ?? 6A ?? 6A ?? 6A ?? 68 ?? ?? ?? ?? 52 FF ?? ?? ?? ?? ?? 8B ?? 83 ?? ?? 75 ?? 53 FF ?? ?? ?? ?? ?? 5F 5E 5B 81 ?? ?? ?? ?? ?? C3 55 6A ?? 8D ?? ?? ?? 6A ?? 50 FF ?? ??  }
	condition:
		all of them
}
rule sampe_tasksche_exe_11 {
	meta:
		description = "Auto-generated simple rule for memory"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		joesandboxid = "269081"
		detection = "malicious"
		source = "memory dumps from processes: process id: 3 frame id: 2 base address: 400000"
		ruletype = "memorycode"
		md5 = "84C82835A5D21BBCF75A61706D8AB549"
		superrule = "no"
		date = "12/05/2017"
	strings:
		// Relevance: 30.115  API Chain: memcpy,??2@YAPAXI@Z,??3@YAXPAX@Z,strcpy,_mbsstr,_mbsstr,_mbsstr,_mbsstr,_mbsstr,strcpy,LocalFileTimeToFileTime,strcmp,??3@YAXPAX@Z,memcpy,
		$code0 = { 55 8B ?? 81 ?? ?? ?? ?? ?? 53 56 57 8B ?? ?? 83 ?? ?? 8B ?? 3B ?? 89 ?? ?? 0F 8C ?? ?? ?? ?? 8B ?? 3B ?? ?? 0F 8D ?? ?? ?? ?? 39 ?? ?? 74 ?? 50 E8 ?? ?? ?? ?? 59 3B ?? ?? ?? ?? ?? 89 ?? ?? 75 ?? 3B ?? 74 ?? 83 ?? ?? 68 ?? ?? ?? ?? 56 FF ?? ?? E8 ?? ?? ?? ?? 83 ?? ?? E9 ?? ?? ?? ?? 3B ?? 75 ?? 8B ?? 8B ?? ?? 8B ?? ?? 89 ?? 33 ?? 88 ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? E9 ?? ?? ?? ?? 8B ?? 3B ?? ?? 7D ?? 50 E8 ?? ?? ?? ?? 59 8B ?? 39 ?? ?? 7D ?? 50 E8 ?? ?? ?? ?? EB }
		// Relevance: 28.065  API Chain: LoadLibraryA,strrchr,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,
		$code1 = { 53 57 E8 ?? ?? ?? ?? 85 ?? 0F 84 ?? ?? ?? ?? 33 ?? 39 ?? ?? ?? ?? ?? 0F 85 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8B ?? 3B ?? 0F 84 ?? ?? ?? ?? 56 8B ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 57 FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 39 ?? ?? ?? ?? ?? A3 ?? ?? ?? ?? 5E 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 3B ?? 74 }
		// Relevance: 26.382  API Chain: GetModuleFileNameA,__p___argc,__p___argv,strcmp,CopyFileA,GetFileAttributesA,strrchr,strrchr,strrchr,SetCurrentDirectoryA,
		$code2 = { 55 8B ?? 81 ?? ?? ?? ?? ?? A0 ?? ?? ?? ?? 53 56 57 88 ?? ?? ?? ?? ?? B9 ?? ?? ?? ?? 33 ?? 8D ?? ?? ?? ?? ?? ?? AB ?? AB AA 8D ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 33 ?? 50 53 FF ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? E8 ?? ?? ?? ?? 59 FF ?? ?? ?? ?? ?? 83 ?? ?? 75 ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8B ?? FF ?? ?? E8 ?? ?? ?? ?? 59 85 ?? 59 75 ?? 53 E8 ?? ?? ?? ?? 85 ?? 59 74 ?? BE ?? ?? ?? ?? 53 8D ?? ?? ?? ?? ?? 56 50 FF ?? ?? ?? ?? ?? 56 FF ?? ?? ?? ?? ?? 83 ?? ?? 74 ?? E8 ?? ?? ?? ?? 85 ?? 0F 85 ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? 6A ?? 50 FF ?? 59 85 ?? 59 74 ?? 8D ?? ?? ?? ?? ?? 6A ?? 50 FF }
		// Relevance: 24.556  API Chain: LoadLibraryA,strrchr,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,GetProcAddress,
		$code3 = { 53 33 ?? 39 ?? ?? ?? ?? ?? 57 0F 85 ?? ?? ?? ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8B ?? 3B ?? 0F 84 ?? ?? ?? ?? 56 8B ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 57 FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 68 ?? ?? ?? ?? 57 A3 ?? ?? ?? ?? FF ?? 39 ?? ?? ?? ?? ?? A3 ?? ?? ?? ?? 5E 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 39 ?? ?? ?? ?? ?? 74 ?? 3B ?? 74 ?? 6A ?? 58 EB ?? 33 ?? 5F 5B C3 }
		// Relevance: 21.272  API Chain: strcpy,wsprintfA,CreateFileA,wsprintfA,??2@YAPAXI@Z,WriteFile,SetFileTime,CloseHandle,
		$code4 = { 55 8B ?? 81 ?? ?? ?? ?? ?? 53 8B ?? ?? 56 83 ?? ?? 57 8B ?? 74 ?? 83 ?? ?? 0F 84 ?? ?? ?? ?? 83 ?? ?? 0F 84 ?? ?? ?? ?? B8 ?? ?? ?? ?? E9 ?? ?? ?? ?? 8B ?? ?? 8B ?? ?? 3B ?? 74 ?? 83 ?? ?? 74 ?? FF ?? E8 ?? ?? ?? ?? 59 8B ?? 83 ?? ?? ?? 3B ?? ?? 7D ?? 3B ?? ?? 7D ?? 50 E8 ?? ?? ?? ?? 59 8B ?? 39 ?? ?? 7D ?? 50 E8 ?? ?? ?? ?? EB ?? FF ?? ?? ?? ?? ?? FF ?? E8 ?? ?? ?? ?? 59 89 ?? ?? 59 8D ?? ?? 50 FF ?? ?? FF ?? ?? FF ?? E8 ?? ?? ?? ?? 8B ?? 83 ?? ?? 85 ?? 7F ?? FF ?? E8 ?? ?? ?? ?? 83 ?? ?? ?? 59 80 ?? ?? ?? 74 ?? 33 ?? E9 ?? ?? ?? ?? 85 ?? 7E ?? B8 ?? ?? ?? ?? E9 ?? ?? ?? ?? 33 ?? 83 ?? ?? 0F }
		// Relevance: 21.075  API Chain: OpenSCManagerA,OpenServiceA,StartServiceA,CloseServiceHandle,sprintf,CreateServiceA,StartServiceA,CloseServiceHandle,CloseServiceHandle,
		$code5 = { 55 8B ?? 81 ?? ?? ?? ?? ?? 57 33 ?? 68 ?? ?? ?? ?? 57 57 89 ?? ?? FF ?? ?? ?? ?? ?? 3B ?? 89 ?? ?? 75 ?? 33 ?? E9 ?? ?? ?? ?? 53 56 BB ?? ?? ?? ?? BE ?? ?? ?? ?? 53 56 50 FF ?? ?? ?? ?? ?? 3B ?? 89 ?? ?? 74 ?? 57 57 50 FF ?? ?? ?? ?? ?? FF ?? ?? FF ?? ?? ?? ?? ?? 6A ?? 5E EB ?? FF ?? ?? 8D ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 50 FF ?? ?? ?? ?? ?? 83 ?? ?? 8D ?? ?? ?? ?? ?? 57 ?? ?? ?? ?? 50 6A ?? 6A ?? 6A ?? 53 56 56 FF ?? ?? FF ?? ?? ?? ?? ?? 8B ?? 3B ?? 74 ?? 57 57 56 FF ?? ?? ?? ?? ?? 56 FF ?? ?? ?? ?? ?? C7 ?? ?? ?? ?? ?? ?? 8B ?? ?? FF ?? ?? FF ?? ?? ?? ?? ?? 8B ?? 5E 5B 5F C9 C3 }
		// Relevance: 19.373  API Chain: MultiByteToWideChar,GetWindowsDirectoryW,swprintf,swprintf,GetFileAttributesW,swprintf,GetTempPathW,wcsrchr,wcsrchr,wcsrchr,
		$code6 = { 55 8B ?? 81 ?? ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 56 BE ?? ?? ?? ?? 57 8B ?? 33 ?? 8D ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? ?? AB ?? AB 8B ?? 33 ?? 8D ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? ?? AB ?? AB 6A ?? 33 ?? 59 8D ?? ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 6A ?? ?? AB ?? AB 8D ?? ?? ?? ?? ?? 50 6A ?? 68 ?? ?? ?? ?? 6A ?? 6A ?? FF ?? ?? ?? ?? ?? BE ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? 56 50 FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? ?? 83 ?? ?? ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? 50 8D ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 50 FF ?? 83 ?? ?? 8D ?? ?? ?? ?? ?? 50 FF ?? ?? ?? ?? ?? 83 ?? ?? 74 ?? FF ?? ?? 8D ?? ?? ?? ?? ?? 50 8D  }
		// Relevance: 19.35  API Chain: strrchr,wcscat,RegCreateKeyW,GetCurrentDirectoryA,strlen,RegSetValueExA,RegQueryValueExA,SetCurrentDirectoryA,RegCloseKey,
		$code7 = { 55 8B ?? 81 ?? ?? ?? ?? ?? 56 57 6A ?? BE ?? ?? ?? ?? 59 8D ?? ?? ?? ?? ?? ?? A5 6A ?? 33 ?? 20 ?? ?? ?? ?? ?? 59 8D ?? ?? ?? ?? ?? 83 ?? ?? ?? ?? AB B9 ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? ?? AB ?? AB AA 8D ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 50 FF ?? ?? ?? ?? ?? 83 ?? ?? ?? 59 59 BF ?? ?? ?? ?? 8D ?? ?? 33 ?? 39 ?? ?? 50 8D ?? ?? ?? ?? ?? 50 75 ?? 68 ?? ?? ?? ?? EB ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 39 ?? ?? 0F 84 ?? ?? ?? ?? 39 ?? ?? 74 ?? 8D ?? ?? ?? ?? ?? 50 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? 50 E8 ?? ?? ?? ?? 59 40 50 8D ?? ?? ?? ?? ?? 50 6A ?? 56 57 FF ?? ?? FF ?? ?? ?? ?? ?? 8B  }
		// Relevance: 16.611  API Chain: EntryPoint,__set_app_type,__p__fmode,__p__commode,_adjust_fdiv,__setusermatherr,_initterm,__getmainargs,_initterm,_acmdln,GetStartupInfoA,GetModuleHandleA,exit,_XcptFilter,
		$code8 = { 55 8B ?? 6A ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? ?? A1 ?? ?? ?? ?? 50 ?? 89 ?? ?? ?? ?? ?? 83 ?? ?? 53 56 57 89 ?? ?? 33 ?? 89 ?? ?? 6A ?? FF ?? ?? ?? ?? ?? 59 83 ?? ?? ?? ?? ?? ?? 83 ?? ?? ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 89 ?? FF ?? ?? ?? ?? ?? 8B ?? ?? ?? ?? ?? 89 ?? A1 ?? ?? ?? ?? 8B ?? A3 ?? ?? ?? ?? E8 ?? ?? ?? ?? 39 ?? ?? ?? ?? ?? 75 ?? 68 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 59 E8 ?? ?? ?? ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? E8 ?? ?? ?? ?? A1 ?? ?? ?? ?? 89 ?? ?? 8D ?? ?? 50 FF ?? ?? ?? ?? ?? 8D ?? ?? 50 8D ?? ?? 50 8D ?? ?? 50 FF ?? ?? ?? ?? ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? E8 ??  }
		// Relevance: 16.084  API Chain: strrchr,??0exception@@QAE@ABQBD@Z,_CxxThrowException,strrchr,??0exception@@QAE@ABQBD@Z,_CxxThrowException,strrchr,??0exception@@QAE@ABQBD@Z,_CxxThrowException,memcpy,memcpy,
		$code9 = { 55 8B ?? 83 ?? ?? 83 ?? ?? ?? 53 56 57 8B ?? 75 ?? 8D ?? ?? 8D ?? ?? 50 C7 ?? ?? ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8D ?? ?? 68 ?? ?? ?? ?? 50 E8 ?? ?? ?? ?? 8B ?? ?? 6A ?? 5B 6A ?? 5F 3B ?? 74 ?? 3B ?? 74 ?? 83 ?? ?? 74 ?? 8D ?? ?? 8D ?? ?? 50 C7 ?? ?? ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8D ?? ?? 68 ?? ?? ?? ?? 50 E8 ?? ?? ?? ?? 8B ?? ?? 3B ?? 74 ?? 3B ?? 74 ?? 83 ?? ?? 74 ?? 8D ?? ?? 8D ?? ?? 50 C7 ?? ?? ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8D ?? ?? 68 ?? ?? ?? ?? 50 E8 ?? ?? ?? ?? 50 89 ?? ?? ?? ?? ?? FF ?? ?? 8D ?? ?? ?? ?? ?? 89 ?? ?? ?? ?? ?? 50 E8 ?? ?? ?? ?? FF ?? ?? ?? ?? ?? 8D ?? ?? ?? ?? ?? FF ??  }
	condition:
		all of them
}
