/*
	Joe Sandbox generates four different rule types based on static and dynamic behavior data:

	 - Sample File (initial sample)
	 - Dropped File (files downloaded or stored during dynamic analysis)
	 - Opcode Memory (instruction opcodes from memory dumps of processes captured during dynamic analysis)

	A rule may be a simple or super rule. Compared to simple rules super rules include artifacts present in multiple files / analyses and are generic.
	Since most malware is packed sample and dropped file rules often do not provide meaningful detection results. In contrast string and opcode
	rules provide good detection capabilities. To scan memory with Yara you can use the specific process ID via command line or use our yarafullmemoryscan.bat to search
	accross all processes on a system.

	This rule file contains simple Sample File rules. Artifact include strings and PE data.

	Automated rule generation is not perfect and therefore we encourage you to modify and extend the rules provided!
*/

import "pe"

rule sampe_mssecsvc_exe_0 {
	meta:
		description = "Auto-generated simple rule for file"
		author = "Joe Sandbox Yara Rule Generator 1.0.0"
		yaraversion = ">= 3.2.0"
		tag = "Joe Sandbox"
		source = "mssecsvc.exe"
		joesandboxid = "269081"
		detection = "malicious"
		ruletype = "sample"
		superrule = "no"
		falsepositiverate = "unknown"
		md5 = "db349b97c37d22f5ea1d1841e3c89eb4"
		sha1 = "e889544aff85ffaf8b0d0da705105dee7c97fe26"
		sha256 = "24d004a104d4d54034dbcffc2a4b19a11f39008a575aa614ea04703480b1022c"
		date = "12/05/2017"
	strings:
		// Relevance: 6.0 Appears at: 251de
		$s0 = "file error" fullword nocase wide ascii
		// Relevance: 6.0 Appears at: 2505d
		$s1 = "cmd.exe /c \"%s\"" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 1d9a4
		$s2 = "userid" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 251a7
		$s3 = "buffer error" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 1c2c7
		$s4 = "Windows 2000 5.0" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 251c6
		$s5 = "data error" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 1c31c
		$s6 = "\\PIPE\\" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 4f12
		$s7 = "launcher.dll" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 4f2e
		$s8 = "WINDOWS" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 1da77
		$s9 = "tasksche.exe" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 25141
		$s10 = "attrib +h ." fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 25404
		$s11 = "%s%s%s" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: a87e
		$s12 = "FlsGetValue" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 251d3
		$s13 = "stream error" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: b1
		$s14 = "@.data" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 1c2b6
		$s15 = "Windows 2000 2195" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 2401d
		$s16 = "OLEAUT32.dll" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 25299
		$s17 = "invalid block type" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 22e4
		$s18 = "Windows 2000 2195" fullword nocase wide ascii
		// Relevance: 3.0 Appears at: 6f34
		$s19 = "VarFileInfo" fullword nocase wide ascii
		// Opcode sequence from the PE entrypoint
		$entrypointOpCode = { 55 8B ?? 6A ?? 68 ?? ?? ?? ?? 68 ?? ?? ?? ?? }
	condition:
		all of them
		// PE Section check
		and pe.sections[0].name contains ".text"
		and pe.sections[1].name contains ".rdata"
		and pe.sections[2].name contains ".data"
		and pe.sections[3].name contains ".rsrc"
		// PE Image characteristic check
		and pe.characteristics & pe.LOCAL_SYMS_STRIPPED
		and pe.characteristics & pe.EXECUTABLE_IMAGE
		and pe.characteristics & pe.LINE_NUMS_STRIPPED
		and pe.characteristics & pe.RELOCS_STRIPPED
		// PE subsystem check
		and pe.subsystem & pe.SUBSYSTEM_WINDOWS_GUI
}
